@@ -78,7 +78,7 @@ bool LibzipPlugin::list()
     }
 
     // Fetch archive comment.
-    m_comment = QString::fromLocal8Bit(zip_get_archive_comment(archive.get(), nullptr, ZIP_FL_ENC_RAW));
+    m_comment = QString::fromUtf8(zip_get_archive_comment(archive.get(), nullptr, ZIP_FL_ENC_GUESS));
 
     // Get number of archive entries.
     const auto nofEntries = zip_get_num_entries(archive.get(), 0);
